Zope 4 documentation
====================
This is the official home for all Zope 4 documentation.


.. note::

    New installations should use Zope 5 instead of Zope 4. Users migrating
    applications from Zope 2 should upgrade to Zope 5 once their application
    supports Zope 4 on Python 3. The Zope developer community strives to make
    sure the next upgrade step to Zope 5 is and remains a quick and painless
    exercise.


.. toctree::
   :maxdepth: 2

   zope4/index
   INSTALL
   operation
   wsgi
   maintenance
   Zope release schedule <https://www.zope.dev/releases.html>
   changes
   zopebook/index
   zdgbook/index
